# Copyright 2009 Canonical Ltd.  All rights reserved.
#
# This file is part of lazr.authentication
#
# lazr.authentication is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, version 3 of the License.
#
# lazr.authentication is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
# License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with lazr.authentication.  If not, see <http://www.gnu.org/licenses/>.
"Test harness for doctests."

# pylint: disable=E0611

__metaclass__ = type
__all__ = [
    'load_tests',
    ]

import atexit
import doctest
import os

# pylint: disable=F0401
from pkg_resources import (
    resource_filename, resource_exists, resource_listdir, cleanup_resources)

DOCTEST_FLAGS = (
    doctest.ELLIPSIS |
    doctest.NORMALIZE_WHITESPACE |
    doctest.REPORT_NDIFF)


# pylint: disable=W0613
def load_tests(loader, tests, pattern):
    """Load all the doctests."""
    doctest_files = []
    if resource_exists('lazr.authentication', 'docs'):
        for name in resource_listdir('lazr.authentication', 'docs'):
            if name.endswith('.rst'):
                doctest_files.append(
                    os.path.abspath(resource_filename(
                        'lazr.authentication', 'docs/%s' % name)))
    atexit.register(cleanup_resources)
    tests.addTest(doctest.DocFileSuite(
        *doctest_files, module_relative=False, optionflags=DOCTEST_FLAGS))
    return tests
